@@ -293,7 +293,7 @@ def release():
     # search for a version file
     versionfilename = ''
     for d in os.walk('.'):
-        if not 'build' in d[0]:
+        if not 'build' in d[0] and not 'lib' in d[0]:
             filename = os.path.join(d[0], '__version__.py')
             if os.path.isfile(filename):
                 versionfilename = filename
